==> vb-react-form-0.0.3.tgz: package/es/form-errors.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import { FormContext } from './form-context';
import { map } from 'lodash';

var FormErrorsComponent = function (_React$Component) {
  _inherits(FormErrorsComponent, _React$Component);

  function FormErrorsComponent() {
    _classCallCheck(this, FormErrorsComponent);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  FormErrorsComponent.prototype.render = function render() {
    var _props = this.props,
        errors = _props.errors,
        other = _objectWithoutProperties(_props, ['errors']);

    return React.createElement(
      'div',
      other,
      map(errors, function (error, key) {
        return React.createElement(
          'div',
          { key: key || 'err' },
          error
        );
      })
    );
  };

  return FormErrorsComponent;
}(React.Component);

var FormErrors = function (_React$Component2) {
  _inherits(FormErrors, _React$Component2);

  function FormErrors(props, context) {
    _classCallCheck(this, FormErrors);

    var _this2 = _possibleConstructorReturn(this, _React$Component2.call(this, props, context));

    _this2.state = { errors: {} };
    return _this2;
  }

  FormErrors.prototype.componentDidMount = function componentDidMount() {
    var _this3 = this;

    this.subscriberId = this.context.form.validators.subscribe(function (errors) {
      var err = {};
      (_this3.props.errors || []).forEach(function (name) {
        err[name] = errors[name];
      });
      _this3.setState({ errors: err });
    });
  };

  FormErrors.prototype.componentWillUnmount = function componentWillUnmount() {
    if (this.subscriberId) {
      this.context.form.validators.removeSubscriber(this.subscriberId);
      this.subscriberId = null;
    }
  };

  FormErrors.prototype.render = function render() {
    var _props2 = this.props,
        component = _props2.component,
        other = _objectWithoutProperties(_props2, ['component']);

    return React.createElement(component || FormErrorsComponent, _extends({}, other, this.state));
  };

  return FormErrors;
}(React.Component);

FormErrors.propTypes = {
  errors: React.PropTypes.arrayOf(React.PropTypes.string).isRequired,
  component: React.PropTypes.func
};

FormErrors.contextTypes = {
  form: React.PropTypes.instanceOf(FormContext).isRequired
};

export { FormErrors };

==> vb-react-form-0.0.7.tgz: package/es/form-errors.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import { FormContext } from './form-context';

var FormErrorsComponent = function (_React$Component) {
  _inherits(FormErrorsComponent, _React$Component);

  function FormErrorsComponent() {
    _classCallCheck(this, FormErrorsComponent);

    return _possibleConstructorReturn(this, _React$Component.apply(this, arguments));
  }

  FormErrorsComponent.prototype.render = function render() {
    var _props = this.props,
        errors = _props.errors,
        errorList = _props.errorList,
        other = _objectWithoutProperties(_props, ['errors', 'errorList']);

    return React.createElement(
      'div',
      other,
      errorList.map(function (error, index) {
        return React.createElement(
          'div',
          { key: index },
          error
        );
      })
    );
  };

  return FormErrorsComponent;
}(React.Component);

var FormErrors = function (_React$Component2) {
  _inherits(FormErrors, _React$Component2);

  function FormErrors(props, context) {
    _classCallCheck(this, FormErrors);

    var _this2 = _possibleConstructorReturn(this, _React$Component2.call(this, props, context));

    _this2.state = { errors: {} };
    return _this2;
  }

  FormErrors.prototype.componentDidMount = function componentDidMount() {
    var _this3 = this;

    this.subscriberId = this.context.form.validators.subscribe(function (errors) {
      var err = {};
      (_this3.props.errors || []).forEach(function (name) {
        err[name] = errors[name];
      });
      _this3.setState({ errors: err });
    });
  };

  FormErrors.prototype.componentWillUnmount = function componentWillUnmount() {
    if (this.subscriberId) {
      this.context.form.validators.removeSubscriber(this.subscriberId);
      this.subscriberId = null;
    }
  };

  FormErrors.prototype.render = function render() {
    var _this4 = this;

    var _props2 = this.props,
        component = _props2.component,
        errors = _props2.errors,
        other = _objectWithoutProperties(_props2, ['component', 'errors']);

    var errorList = errors.map(function (key) {
      return _this4.state.errors[key];
    }).filter(function (error) {
      return !!error;
    });
    return React.createElement(component || FormErrorsComponent, _extends({}, other, this.state, { errorList: errorList }));
  };

  return FormErrors;
}(React.Component);

FormErrors.propTypes = {
  errors: React.PropTypes.arrayOf(React.PropTypes.string).isRequired,
  component: React.PropTypes.func
};

FormErrors.contextTypes = {
  form: React.PropTypes.instanceOf(FormContext).isRequired
};

export { FormErrors };
